@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021 Pier Carlo Chiodi
+# Copyright (C) 2017-2022 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -115,14 +115,18 @@ class ConfigureCommand(ARouteServerCommand):
                 return False, None
         return True, res
 
-    #def ask_16bit_int(self, text, raise_exc=False):
-    #    answer_given, v = self.ask.ask_int(text, None, None, raise_exc)
-    #    if not answer_given:
-    #        return False, None
-    #    if v > 65535:
-    #        print("Invalid input: a 16-bit integer is expected.")
-    #        return False, None
-    #    return True, v
+    def ask_16bit_placeholder_asn(self, text, raise_exc=False, default=None):
+        answer_given, v = self.ask.ask_int(text, default, raise_exc)
+        if not answer_given:
+            return False, None
+        if v > 65535:
+            print("Invalid input: a 16-bit integer is expected.")
+            return False, None
+        if not 64512 <= v <= 65534:
+            print("To avoid potential overlapping with peers' ASN, only "
+                  "values in the 64512-65534 can be used")
+            return False, None
+        return True, v
 
     def collect_answers(self):
         if self.answers:
@@ -168,19 +172,16 @@ class ConfigureCommand(ARouteServerCommand):
             self.wr_text(
                 "Since the ASN used for the route server is "
                 "a 32-bit value, features and services offered "
-                "to clients using BGP communities "
-                "will be configured to use a placeholder 16 bit "
-                "ASN: 65534",
-                #"can be "
-                #"automatically configured only if a 16-bit "
-                #"placeholder ASN is also given "
-                #"(with the exception of BGP Large Communities).",
+                "to clients using (standard) BGP communities "
+                "need to be configured using a placeholder 16 bit "
+                "ASN. Please provide the value of the 16 bit ASN "
+                "to be used as placeholder (range: 64512-65534).",
                 title="Place-holder 16-bit ASN for BGP communities"
             )
-            #self.add_answer("comms_asn", self.ask_16bit_int,
-            #    "16-bit ASN used for BGP communities"
-            #)
-            self.answers["comms_asn"] = 65534
+            self.add_answer("comms_asn", self.ask_16bit_placeholder_asn,
+               "16-bit placeholder ASN used for BGP communities",
+               default="65534"
+            )
 
         self.wr_text(
             None, title="Route server's BGP router-id"
@@ -236,6 +237,27 @@ class ConfigureCommand(ARouteServerCommand):
                             rs_as=rs_as
                         )
 
+        def add_euroix_reject_code_comm(code, lrg=None):
+            # https://www.euro-ix.net/en/forixps/large-bgp-communities/
+
+            if self.answers["daemon"] == "openbgpd" and \
+               version.parse(self.answers["version"]) < version.parse("6.1"):
+                # Euro-IX communities are based on Large BGP Communities, which are
+                # not available in OpenBGPD 6.0 or older.
+                return
+
+            assert isinstance(code, int)
+
+            if "reject_cause_map" not in cfg["communities"]:
+                cfg["communities"]["reject_cause_map"] = {}
+
+            if code in cfg["communities"]["reject_cause_map"]:
+                raise ValueError(f"Duplicate code: {code}")
+
+            cfg["communities"]["reject_cause_map"][code] = {
+                "lrg": lrg.replace("RS", "rs_as")
+            }
+
         res = OrderedDict()
         res["cfg"] = OrderedDict()
         cfg = res["cfg"]
@@ -269,7 +291,7 @@ class ConfigureCommand(ARouteServerCommand):
         filtering["ipv4_pref_len"] = {"min": 8, "max": 24}
         filtering["ipv6_pref_len"] = {"min": 12, "max": 48}
         self.notes.append(
-            "Accepted prefix lengths are 8-24 for IPv6 and 12-48 for IPv6."
+            "Accepted prefix lengths are 8-24 for IPv4 and 12-48 for IPv6."
         )
 
         filtering["global_black_list_pref"] = []
@@ -358,6 +380,13 @@ class ConfigureCommand(ARouteServerCommand):
             filtering["reject_policy"] = {
                 "policy": "tag_and_reject"
             }
+        else:
+            filtering["reject_policy"] = {
+                "policy": "tag"
+            }
+            self.notes.append(
+                "Rejected routes are kept but not advertised to clients."
+            )
 
         if (
             self.answers["daemon"] == "bird" and \
@@ -387,10 +416,50 @@ class ConfigureCommand(ARouteServerCommand):
 
         cfg["communities"] = OrderedDict()
 
-        if self.answers["daemon"] == "bird":
+        if filtering["reject_policy"]["policy"] in ("tag_and_reject", "tag"):
             add_comm("reject_cause",
                      "65520:dyn_val", "rs_as:65520:dyn_val")
 
+            # 1 == Invalid AS_PATH length == AS path too long
+            add_euroix_reject_code_comm(1, "RS:1101:5")
+
+            # 2 == Prefix is bogon == Bogon Prefix
+            add_euroix_reject_code_comm(2, "RS:1101:3")
+
+            # 3 == Prefix is in global blacklist == <missing>
+
+            # 4 == Invalid AFI == <missing>
+
+            # 5 == Invalid NEXT_HOP == next hop IP != peer IP
+            add_euroix_reject_code_comm(5, "RS:1101:8")
+
+            # 6 == Invalid left-most ASN == as-path.first != peeras
+            add_euroix_reject_code_comm(6, "RS:1101:7")
+
+            # 7 == Invalid ASN in AS_PATH == Bogon AS
+            add_euroix_reject_code_comm(7, "RS:1101:4")
+
+            # 8 == Transit-free ASN in AS_PATH == transit-free ASN in AS-Path
+            add_euroix_reject_code_comm(8, "RS:1101:14")
+
+            # 9 == Origin ASN not in IRRDB AS-SETs == Origin AS not in peer AS-SET
+            add_euroix_reject_code_comm(9, "RS:1101:10")
+
+            # 10 == IPv6 prefix not in global unicast space == Bogon Prefix
+            add_euroix_reject_code_comm(10, "RS:1101:3")
+
+            # 11 == Prefix is in client blacklist == <missing>
+
+            # 12 == Prefix not in IRRDB AS-SETs == IRRDB Prefix not found in AS-SET or aut-num
+            add_euroix_reject_code_comm(12, "RS:1101:9")
+
+            # 13 == Invalid prefix length == <missing, there's only too long/short>
+
+            # 14 == RPKI INVALID route == Prefix is RPKI INVALID
+            add_euroix_reject_code_comm(14, "RS:1101:13")
+
+            # 15 == Never via route-servers ASN in AS_PATH == <missing>
+
         add_comm("prefix_present_in_as_set",
                  "64512:11", "rs_as:64512:11")
         add_comm("prefix_not_present_in_as_set",
@@ -404,26 +473,35 @@ class ConfigureCommand(ARouteServerCommand):
         add_comm("route_validated_via_white_list",
                  "64512:41", "rs_as:64512:41")
 
+        add_comm("rpki_bgp_origin_validation_not_performed",
+                 "64512:50", "rs_as:1000:3")  # Euro-IX
+        add_comm("rpki_bgp_origin_validation_valid",
+                 "64512:51", "rs_as:1000:1")  # Euro-IX
+        add_comm("rpki_bgp_origin_validation_unknown",
+                 "64512:52", "rs_as:1000:2")  # Euro-IX
+        add_comm("rpki_bgp_origin_validation_invalid",
+                 "64512:53", "rs_as:1000:4")  # Euro-IX
+
         add_comm("do_not_announce_to_any",
-                 "0:{rs_as}", "rs_as:0:0")
+                 "0:{rs_as}", "rs_as:0:0")  # Euro-IX
         add_comm("do_not_announce_to_peer",
-                 "0:peer_as", "rs_as:0:peer_as")
+                 "0:peer_as", "rs_as:0:peer_as")  # Euro-IX
         add_comm("announce_to_peer",
-                 "{rs_as}:peer_as", "rs_as:1:peer_as")
+                 "{rs_as}:peer_as", "rs_as:1:peer_as")  # Euro-IX
 
         add_comm("prepend_once_to_any",
-                 "65501:{rs_as}", "rs_as:101:0")
+                 "65501:{rs_as}", "rs_as:101:0")  # Euro-IX
         add_comm("prepend_twice_to_any",
-                 "65502:{rs_as}", "rs_as:102:0")
+                 "65502:{rs_as}", "rs_as:102:0")  # Euro-IX
         add_comm("prepend_thrice_to_any",
-                 "65503:{rs_as}", "rs_as:103:0")
+                 "65503:{rs_as}", "rs_as:103:0")  # Euro-IX
 
         add_comm("prepend_once_to_peer",
-                 "65511:peer_as", "rs_as:101:peer_as")
+                 "65511:peer_as", "rs_as:101:peer_as")  # Euro-IX
         add_comm("prepend_twice_to_peer",
-                 "65512:peer_as", "rs_as:102:peer_as")
+                 "65512:peer_as", "rs_as:102:peer_as")  # Euro-IX
         add_comm("prepend_thrice_to_peer",
-                 "65513:peer_as", "rs_as:103:peer_as")
+                 "65513:peer_as", "rs_as:103:peer_as")  # Euro-IX
 
         add_comm("add_noexport_to_peer",
                  "65281:peer_as", "rs_as:65281:peer_as")
