@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021 Pier Carlo Chiodi
+# Copyright (C) 2017-2022 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -113,7 +113,7 @@ class LiveScenario(ARouteServerTestCase):
       The value of this attribute must be a regular expression that
       matches the standard, extended or large BGP communities used to
       tag invalid routes. For example, if the standard BGP community
-      ``65520:dyn_val`` is used, the value must be ``^65520:(\d+)$``.
+      ``65520:dyn_val`` is used, the value must be ``^65520:(\\d+)$``.
       If this attribute is not None, routes that have LOCAL_PREF == 1
       and the ``reject_cause`` BGP community with ``dyn_val == 0``
       are considered as filtered.
@@ -134,7 +134,7 @@ class LiveScenario(ARouteServerTestCase):
             self.rs = self._get_instance_by_name("rs")
 
     Set the ``__test__`` attribute of derived classes to False to avoid them
-    to be used directly by ``nose`` to run tests; only the specific IPv4/IPv6
+    to be used directly by ``pytest`` to run tests; only the specific IPv4/IPv6
     class (the one where the ``DATA`` dictionary is set) must have
     ``__test__`` == True.
     """
@@ -396,6 +396,9 @@ class LiveScenario(ARouteServerTestCase):
             os.makedirs(dest_dir)
 
         for instance in cls.INSTANCES:
+            if not isinstance(instance, BGPSpeakerInstance):
+                continue
+
             path = os.path.join(dest_dir, "{}.txt".format(instance.name))
             routes = instance.get_routes(None, include_filtered=True)
             sorted_routes = sorted(routes,
@@ -878,6 +881,8 @@ class LiveScenario_TagRejectPolicy(object):
     if the ``reject_policy.policy`` is ``tag``, the ``65520:dyn_val``
     value is used for the ``reject_cause`` BGP community and the
     ``rt:65520:dyn_val`` value for the ``rejected_route_announced_by`` one.
+    Additionally, using the ``reject_cause_map``, some reject codes are
+    mapped to specific BGP communities in the ``rs_as:1101:*`` range.
 
     The ``general.yml`` file, or the file given in the ``orig_file`` argument
     of ``_get_cfg_general`` method, is cloned and reconfigured with the
@@ -896,8 +901,8 @@ class LiveScenario_TagRejectPolicy(object):
 
     """
 
-    REJECT_CAUSE_COMMUNITY = "^65520:(\d+)$"
-    REJECTED_ROUTE_ANNOUNCED_BY_COMMUNITY = "^rt:65520:(\d+)$"
+    REJECT_CAUSE_COMMUNITY = r"^65520:(\d+)$"
+    REJECTED_ROUTE_ANNOUNCED_BY_COMMUNITY = r"^rt:65520:(\d+)$"
     REJECT_POLICY = "tag"
 
     @classmethod
@@ -914,6 +919,11 @@ class LiveScenario_TagRejectPolicy(object):
             cfg["cfg"]["communities"] = {}
         cfg["cfg"]["communities"]["reject_cause"] = {"std": "65520:dyn_val"}
         cfg["cfg"]["communities"]["rejected_route_announced_by"] = {"ext": "rt:65520:dyn_val"}
+        cfg["cfg"]["communities"]["reject_cause_map"] = {
+            6: {
+                "lrg": "rs_as:1101:7"
+            }
+        }
 
         with open(dest_path, "w") as f:
             yaml.safe_dump(cfg, f, default_flow_style=False)
