@@ -13,8 +13,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import six
-
 from pierky.arouteserver.tests.live_tests.base import LiveScenario
 from pierky.arouteserver.tests.live_tests.bird import BIRDInstanceIPv4, \
                                                       BIRDInstanceIPv6
@@ -112,7 +110,7 @@ class SkeletonScenario(LiveScenario):
         pierky.arouteserver.tests.live_tests.base.LiveScenario.log_contains
     """
 
-    # Leave this to False to avoid nose to use this abstract class to run
+    # Leave this to False to avoid pytest to use this abstract class to run
     # tests. Only derived, more specific classes (test_XXX.py) must have
     # this set to True.
     __test__ = False
@@ -309,7 +307,7 @@ class SkeletonScenario(LiveScenario):
                            other_inst=self.AS2, as_path="2",
                            filtered=True)
         # AS1 should not receive the bogon prefix from the route server
-        with six.assertRaisesRegex(self, AssertionError, "Routes not found"):
+        with self.assertRaisesRegex(AssertionError, "Routes not found"):
             self.receive_route(self.AS1, self.DATA["AS2_bogon1"])
 
     def test_030_custom_test(self):
